@@ -22,12 +22,10 @@ class CFG(AbstractPrinter):
                 continue
             for function in contract.functions + contract.modifiers:
                 if filename:
-                    new_filename = "{}-{}-{}.dot".format(
-                        filename, contract.name, function.full_name
-                    )
+                    new_filename = f"{filename}-{contract.name}-{function.full_name}.dot"
                 else:
-                    new_filename = "{}-{}.dot".format(contract.name, function.full_name)
-                info += "Export {}\n".format(new_filename)
+                    new_filename = f"{contract.name}-{function.full_name}.dot"
+                info += f"Export {new_filename}\n"
                 content = function.slithir_cfg_to_dot_str()
                 with open(new_filename, "w", encoding="utf8") as f:
                     f.write(content)
