@@ -1,4 +1,6 @@
 import argparse
+import logging
+import sys
 
 from crytic_compile import cryticparser
 
@@ -25,6 +27,9 @@ def parse_args() -> argparse.Namespace:
 
 
 def main():
+    # log on stdout to keep output in order
+    logging.basicConfig(stream=sys.stdout, level=logging.DEBUG, force=True)
+
     args = parse_args()
     kwargs = vars(args)
 
