@@ -1,4 +1,12 @@
-from slither.core.expressions import BinaryOperationType, Literal, UnaryOperationType
+from fractions import Fraction
+from slither.core.expressions import (
+    BinaryOperationType,
+    Literal,
+    UnaryOperationType,
+    Identifier,
+    BinaryOperation,
+    UnaryOperation,
+)
 from slither.utils.integer_conversion import convert_string_to_fraction, convert_string_to_int
 from slither.visitors.expression.expression import ExpressionVisitor
 
@@ -27,9 +35,15 @@ class ConstantFolding(ExpressionVisitor):
         super().__init__(expression)
 
     def result(self):
-        return Literal(int(get_val(self._expression)), self._type)
+        value = get_val(self._expression)
+        if isinstance(value, Fraction):
+            value = int(value)
+            # emulate 256-bit wrapping
+            if str(self._type).startswith("uint"):
+                value = value & (2**256 - 1)
+        return Literal(value, self._type)
 
-    def _post_identifier(self, expression):
+    def _post_identifier(self, expression: Identifier):
         if not expression.value.is_constant:
             raise NotConstant
         expr = expression.value.expression
@@ -37,9 +51,10 @@ class ConstantFolding(ExpressionVisitor):
         if not isinstance(expr, Literal):
             cf = ConstantFolding(expr, self._type)
             expr = cf.result()
-        set_val(expression, convert_string_to_int(expr.value))
+        set_val(expression, convert_string_to_int(expr.converted_value))
 
-    def _post_binary_operation(self, expression):
+    # pylint: disable=too-many-branches
+    def _post_binary_operation(self, expression: BinaryOperation):
         left = get_val(expression.expression_left)
         right = get_val(expression.expression_right)
         if expression.type == BinaryOperationType.POWER:
@@ -53,18 +68,39 @@ class ConstantFolding(ExpressionVisitor):
         elif expression.type == BinaryOperationType.ADDITION:
             set_val(expression, left + right)
         elif expression.type == BinaryOperationType.SUBTRACTION:
-            if (left - right) < 0:
-                # Could trigger underflow
-                raise NotConstant
             set_val(expression, left - right)
+        # Convert to int for operations not supported by Fraction
         elif expression.type == BinaryOperationType.LEFT_SHIFT:
-            set_val(expression, left << right)
+            set_val(expression, int(left) << int(right))
         elif expression.type == BinaryOperationType.RIGHT_SHIFT:
-            set_val(expression, left >> right)
+            set_val(expression, int(left) >> int(right))
+        elif expression.type == BinaryOperationType.AND:
+            set_val(expression, int(left) & int(right))
+        elif expression.type == BinaryOperationType.CARET:
+            set_val(expression, int(left) ^ int(right))
+        elif expression.type == BinaryOperationType.OR:
+            set_val(expression, int(left) | int(right))
+        elif expression.type == BinaryOperationType.LESS:
+            set_val(expression, int(left) < int(right))
+        elif expression.type == BinaryOperationType.LESS_EQUAL:
+            set_val(expression, int(left) <= int(right))
+        elif expression.type == BinaryOperationType.GREATER:
+            set_val(expression, int(left) > int(right))
+        elif expression.type == BinaryOperationType.GREATER_EQUAL:
+            set_val(expression, int(left) >= int(right))
+        elif expression.type == BinaryOperationType.EQUAL:
+            set_val(expression, int(left) == int(right))
+        elif expression.type == BinaryOperationType.NOT_EQUAL:
+            set_val(expression, int(left) != int(right))
+        # Convert boolean literals from string to bool
+        elif expression.type == BinaryOperationType.ANDAND:
+            set_val(expression, left == "true" and right == "true")
+        elif expression.type == BinaryOperationType.OROR:
+            set_val(expression, left == "true" or right == "true")
         else:
             raise NotConstant
 
-    def _post_unary_operation(self, expression):
+    def _post_unary_operation(self, expression: UnaryOperation):
         # Case of uint a = -7; uint[-a] arr;
         if expression.type == UnaryOperationType.MINUS_PRE:
             expr = expression.expression
@@ -72,15 +108,18 @@ class ConstantFolding(ExpressionVisitor):
                 cf = ConstantFolding(expr, self._type)
                 expr = cf.result()
             assert isinstance(expr, Literal)
-            set_val(expression, -convert_string_to_fraction(expr.value))
+            set_val(expression, -convert_string_to_fraction(expr.converted_value))
         else:
             raise NotConstant
 
-    def _post_literal(self, expression):
-        try:
-            set_val(expression, convert_string_to_fraction(expression.value))
-        except ValueError as e:
-            raise NotConstant from e
+    def _post_literal(self, expression: Literal):
+        if expression.converted_value in ["true", "false"]:
+            set_val(expression, expression.converted_value)
+        else:
+            try:
+                set_val(expression, convert_string_to_fraction(expression.converted_value))
+            except ValueError as e:
+                raise NotConstant from e
 
     def _post_assignement_operation(self, expression):
         raise NotConstant
@@ -115,9 +154,12 @@ class ConstantFolding(ExpressionVisitor):
                 cf = ConstantFolding(expression.expressions[0], self._type)
                 expr = cf.result()
                 assert isinstance(expr, Literal)
-                set_val(expression, convert_string_to_fraction(expr.value))
+                set_val(expression, convert_string_to_fraction(expr.converted_value))
                 return
         raise NotConstant
 
     def _post_type_conversion(self, expression):
-        raise NotConstant
+        cf = ConstantFolding(expression.expression, self._type)
+        expr = cf.result()
+        assert isinstance(expr, Literal)
+        set_val(expression, convert_string_to_fraction(expr.converted_value))
