@@ -52,7 +52,7 @@ def set_solc(test_item: Test):  # pylint: disable=too-many-lines
 
 
 def id_test(test_item: Test):
-    return f"{test_item.detector}: {test_item.solc_ver}/{test_item.test_file}"
+    return f"{test_item.detector.__name__}-{test_item.solc_ver}-{test_item.test_file}"
 
 
 ALL_TEST_OBJECTS = [
@@ -362,6 +362,10 @@ ALL_TEST_OBJECTS = [
         "DAO.sol",
         "0.4.25",
     ),
+    # Test the nonReentrant filtering
+    Test(all_detectors.ReentrancyEth, "reentrancy_with_non_reentrant.sol", "0.8.10"),
+    # Test parse_ignore_comments
+    Test(all_detectors.ReentrancyEth, "reentrancy_filtered_comments.sol", "0.8.10"),
     Test(
         all_detectors.UninitializedStorageVars,
         "uninitialized_storage_pointer.sol",
@@ -476,28 +480,53 @@ ALL_TEST_OBJECTS = [
         "0.7.6",
     ),
     Test(
-        all_detectors.ConstCandidateStateVars,
+        all_detectors.CouldBeConstant,
         "const_state_variables.sol",
         "0.4.25",
     ),
     Test(
-        all_detectors.ConstCandidateStateVars,
+        all_detectors.CouldBeConstant,
         "const_state_variables.sol",
         "0.5.16",
     ),
     Test(
-        all_detectors.ConstCandidateStateVars,
+        all_detectors.CouldBeConstant,
         "const_state_variables.sol",
         "0.6.11",
     ),
     Test(
-        all_detectors.ConstCandidateStateVars,
+        all_detectors.CouldBeConstant,
         "const_state_variables.sol",
         "0.7.6",
     ),
     Test(
-        all_detectors.ConstCandidateStateVars,
-        "immutable.sol",
+        all_detectors.CouldBeConstant,
+        "const_state_variables.sol",
+        "0.8.0",
+    ),
+    Test(
+        all_detectors.CouldBeImmutable,
+        "immut_state_variables.sol",
+        "0.4.25",
+    ),
+    Test(
+        all_detectors.CouldBeImmutable,
+        "immut_state_variables.sol",
+        "0.5.16",
+    ),
+    Test(
+        all_detectors.CouldBeImmutable,
+        "immut_state_variables.sol",
+        "0.6.11",
+    ),
+    Test(
+        all_detectors.CouldBeImmutable,
+        "immut_state_variables.sol",
+        "0.7.6",
+    ),
+    Test(
+        all_detectors.CouldBeImmutable,
+        "immut_state_variables.sol",
         "0.8.0",
     ),
     Test(
@@ -1553,6 +1582,27 @@ ALL_TEST_OBJECTS = [
         "permit_domain_state_var_collision.sol",
         "0.8.0",
     ),
+    Test(
+        all_detectors.VarReadUsingThis,
+        "var_read_using_this.sol",
+        "0.4.25",
+    ),
+    Test(
+        all_detectors.VarReadUsingThis,
+        "var_read_using_this.sol",
+        "0.5.16",
+    ),
+    Test(all_detectors.VarReadUsingThis, "var_read_using_this.sol", "0.6.11"),
+    Test(
+        all_detectors.VarReadUsingThis,
+        "var_read_using_this.sol",
+        "0.7.6",
+    ),
+    Test(
+        all_detectors.VarReadUsingThis,
+        "var_read_using_this.sol",
+        "0.8.15",
+    ),
 ]
 
 
